# Host

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cpu_model** | **str** |  | 
**create_time** | **datetime** |  | 
**gpu_free** | **int** |  | 
**gpu_model** | **str** |  | 
**gpu_used** | **int** |  | 
**machine_type** | **str** |  | 
**memory_gib_free** | **int** |  | 
**memory_gib_used** | **int** |  | 
**name** | **str** |  | 
**online** | **bool** |  | 
**update_time** | **datetime** |  | 
**vcpu_free** | **int** |  | 
**vcpu_per_cpu_thread** | **int** |  | 
**vcpu_used** | **int** |  | 
**vm_count** | **int** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


